@@ -239,7 +239,7 @@ svcauth_gss_accept_sec_context(struct svc_req *rqst,
 	/* Deserialize arguments. */
 	memset(&recv_tok, 0, sizeof(recv_tok));
 
-	if (!svc_getargs(rqst->rq_xprt, xdr_rpc_gss_init_args,
+	if (!svc_getargs(rqst->rq_xprt, (xdrproc_t)xdr_rpc_gss_init_args,
 			 (caddr_t)&recv_tok)) {
 		authgss_log_err("svcauth_gss_accept_sec_context: "
 			"svc_getargs failed\n");
@@ -315,7 +315,7 @@ svcauth_gss_accept_sec_context(struct svc_req *rqst,
 		gss_release_buffer(&min_stat, &gr->gr_token);
 	}
 
-	svc_freeargs(rqst->rq_xprt, xdr_rpc_gss_init_args, (caddr_t)&recv_tok);
+	svc_freeargs(rqst->rq_xprt, (xdrproc_t)xdr_rpc_gss_init_args, (caddr_t)&recv_tok);
 
 	AUTHGSS_DEBUG(1, ("svcauth_gss_accept_sec_context: "
 		      "gss_accept_sec_context returned %x:%x",
@@ -346,6 +346,16 @@ svcauth_gss_accept_sec_context(struct svc_req *rqst,
 	gd->sec.mech = mech;
 	gd->sec.qop = GSS_C_QOP_DEFAULT;
 	gd->sec.svc = gc->gc_svc;
+
+	switch(gd->sec.svc) {
+        case RPCSEC_GSS_SVC_PRIVACY: 
+        	AUTHGSS_DEBUG(1, ("PRIVACY SERVICE\n")); break; 
+        case RPCSEC_GSS_SVC_INTEGRITY:
+        	AUTHGSS_DEBUG(1, ("INTEGRITY SERVICE\n")); break; 
+        case RPCSEC_GSS_SVC_NONE:
+        	AUTHGSS_DEBUG(1, ("NO SERVICE\n")); break; 
+        }
+
 	gd->seq = gc->gc_seq;
 	gd->win = gr->gr_win;
 
@@ -592,7 +602,7 @@ _svcauth_gss(struct svc_req *rqst, struct rpc_msg *msg, bool_t *no_dispatch)
 
 		*no_dispatch = TRUE;
 
-		call_stat = svc_sendreply(rqst->rq_xprt, xdr_rpc_gss_init_res,
+		call_stat = svc_sendreply(rqst->rq_xprt, (xdrproc_t)xdr_rpc_gss_init_res,
 					  (caddr_t)&gr);
 
 		gss_release_buffer(&min_stat, &gr.gr_token);
@@ -635,7 +645,7 @@ _svcauth_gss(struct svc_req *rqst, struct rpc_msg *msg, bool_t *no_dispatch)
 	}
 	retstat =  AUTH_OK;
 freegc:
-	xdr_free(xdr_rpc_gss_cred, gc);
+	xdr_free((xdrproc_t)xdr_rpc_gss_cred, (char *)gc);
 	AUTHGSS_DEBUG(1, ("svcauth_gss: returning %d", retstat));
 	return (retstat);
 }
